``pygcam.units``
============================

This module contains functions and classes that support symbolic constants
usable by the chart command (and user code) for on-the-fly data conversion.

API
---

.. automodule:: pygcam.units
   :members:
